﻿using System.Collections;
using System.Collections.ObjectModel;
using System.ComponentModel;

namespace TestProject
{
    /// <summary>
    /// 메인 윈도우 뷰 모델
    /// </summary>
    public class MainWindowViewModel : INotifyPropertyChanged
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Event
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 속성 변경시 이벤트 - PropertyChanged

        /// <summary>
        /// 속성 변경시 이벤트
        /// </summary>
        public event PropertyChangedEventHandler PropertyChanged;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 제목
        /// </summary>
        private string title = "Behavior<T> 클래스 : 리스트 박스 선택 동작 사용하기";

        /// <summary>
        /// 성명 리스트
        /// </summary>
        private IList nameList = null;

        /// <summary>
        /// 선택 성명 리스트
        /// </summary>
        private IList selectedNameList = null;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Property
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 제목 - Title

        /// <summary>
        /// 제목
        /// </summary>
        public string Title
        {
            get
            {
                return this.title;
            }
            set
            {
                this.title = value;

                FirePropertyChangedEvent(nameof(Title));
            }
        }

        #endregion

        #region 성명 리스트 - NameList

        /// <summary>
        /// 성명 리스트
        /// </summary>
        public IList NameList
        {
            get
            {
                return this.nameList;
            }
            set
            {
                this.nameList = value;

                FirePropertyChangedEvent(nameof(NameList));
            }
        }

        #endregion
        #region 선택 성명 리스트 - SelectedNameList

        /// <summary>
        /// 선택 성명 리스트
        /// </summary>
        public IList SelectedNameList
        {
            get
            {
                return this.selectedNameList;
            }
            set
            {
                this.selectedNameList = value;

                FirePropertyChangedEvent(nameof(SelectedNameList));
            }
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainWindowViewModel()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainWindowViewModel()
        {
            ObservableCollection<string> nameCollection = new ObservableCollection<string>();

            nameCollection.Add("홍길동");
            nameCollection.Add("김철수");
            nameCollection.Add("이영희");
            nameCollection.Add("김순희");

            this.nameList = nameCollection;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Protected

        #region 속성 변경시 이벤트 발생시키기 - FirePropertyChangedEvent(propertyName)

        /// <summary>
        /// 속성 변경시 이벤트 발생시키기
        /// </summary>
        /// <param name="propertyName">속성명</param>
        protected void FirePropertyChangedEvent(string propertyName)
        {
            PropertyChanged?.Invoke(this, new PropertyChangedEventArgs(propertyName));
        }

        #endregion
    }
}